# Cuckoo Filter: Practically Better Than Bloom

This repository is an implementation of [Cuckoo Filter: Practically Better Than Bloom](Cuckoo_Filter_Practically_Better_Than_Bloom.pdf) paper introduced by Bin Fan, David G. Andersen, Michael Kaminsky, and Michael D. Mitzenmacher.

## Installation
You can install the package by issuing the following command:

	pip install cuckoo-filter

## Contributors
[Ali Moallim](mailto:axj.159@gmail.com)

## License
This code is licensed under [GNU GPL v3](https://www.gnu.org/licenses/gpl-3.0.en.html).

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
